@@ -14,13 +14,15 @@ use Getopt::Long;
 GetOptions(
    'i|interval=i'   => \(my $INTERVAL = 10),
    'p|print-config' => \my $PRINT_CONFIG,
+   'addr|a=s'       => \my $ADDR,
 
    'adapter|A=s' => \my $ADAPTER,
 ) or exit 1;
 
 my $chip = Device::Chip::BME280->new;
 await $chip->mount(
-   Device::Chip::Adapter->new_from_description( $ADAPTER )
+   Device::Chip::Adapter->new_from_description( $ADAPTER ),
+   addr => $ADDR,
 );
 
 await $chip->protocol->power(1);
